from .view_perfil import *
from .view_informasaun import *
from .view_produtu import *
from .view_parceiru import *
from .view_anunsiu import *
from .view_order import *